/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */

// @ts-check

/** @type {import('@docusaurus/plugin-content-docs').SidebarsConfig} */
const sidebars = {
    // By default, Docusaurus generates a sidebar from the docs folder structure
    // tutorialSidebar: [{ type: 'autogenerated', dirName: '.' }],

    // But you can create a sidebar manually
    tutorialSidebar: [{
        type: 'doc',
        id: 'index'
    }, {
        type: 'category',
        label: 'Getting Started',
        collapsed: false,
        items: [{
            type: 'doc',
            id: 'installing_devbox'
        }, {
            type: 'doc',
            id: 'quickstart'
        }, {
            type: 'doc',
            id: 'devbox_global'
        },{
            type: 'doc',
            id: 'devbox_cloud/index'
        }]
    }, {
        type: 'category',
        label: 'Configuring your Project',
        collapsed: true,
        items: [{
            type: 'doc',
            id: 'guides/pinning_packages'
        }, {
            type: 'doc',
            id: 'guides/platform_specific_packages'
        }, {
            type: 'doc',
            id: 'guides/using_flakes'
        },{
            type: 'doc',
            id: 'guides/scripts'
        }, {
            type: 'doc',
            id: 'guides/plugins'
        }, {
            type: 'doc',
            id: 'guides/creating_plugins'
        },{
            type: 'doc',
            id: 'guides/services'
        }]
    }, {
        type: 'category',
        label: 'Using Devbox with Jetify Cloud',
        link: { type: 'doc', id: 'cloud/index' },
        collapsed: true,
            items: [
            {
                type: 'doc',
                label: "Introduction to Jetify Cloud",
                id: 'cloud/index'

            },{
                type:'category',
                label: 'Managing your Team',
                items: [{
                    type: 'autogenerated',
                    dirName: 'cloud/dashboard'
                }]
            },{
                type: 'category',
                label: 'Caching your Project Packages with Jetify Cache',
                items: [{
                    type: 'autogenerated',
                    dirName: 'cloud/cache'
                }]
            },{
                type: 'category',
                label: 'Syncing and Managing Secrets with Jetify Secrets',
                items: [{
                    type: 'autogenerated',
                    dirName: 'cloud/secrets'
                }]
            },{
                type: 'category',
                label: 'Deploying your Project with Jetify Deployments',
                items: [{ 
                    type: 'autogenerated',
                    dirName: 'cloud/deploys'
                }]
            }, {
                type: 'doc',
                id: 'cloud/faq'
            }]
    },{
        type: 'category',
        label: 'Reference',
        collapsed: false,
        items: [{
            type: 'category',
            label: "CI/CD Reference",
            collapsed: true,
            items: [{
                type: 'doc',
                id: 'continuous_integration/github_action'
            }]
        }, {
            type: 'category',
            label: "CLI Reference",
            collapsed: true,
            link: { type: 'doc', id: 'cli_reference/devbox' },
            items: [{
                type: 'autogenerated',
                dirName: 'cli_reference'
            }]
        }, {
            type: 'doc',
            id: 'configuration'
        }, {
            type: 'doc',
            id: 'devbox_cloud/beta_faq'
        },{
            type: 'category',
            label: "IDE Reference",
            collapsed: true,
            items: [{
                type: 'doc',
                id: 'ide_configuration/direnv',
            }, {
                type: 'doc',
                id: 'ide_configuration/eclipse',
            }, {
                type: 'doc',
                id: 'ide_configuration/vscode'
            }]
        }]
    }, {
        type: 'category',
        label: "Examples",
        link: { type: 'doc', id: 'devbox_examples/index' },
        items: [{
            type: 'category',
            label: 'Languages',
            collapsed: true,
            items: [{
                type: 'autogenerated',
                dirName: 'devbox_examples/languages'
            }]
        }, {
            type: 'category',
            label: 'Databases',
            collapsed: true,
            items: [{
                type: 'autogenerated',
                dirName: 'devbox_examples/databases'
            }]
        }, {
            type: 'category',
            label: 'Servers',
            collapsed: true,
            items: [{
                type: 'autogenerated',
                dirName: 'devbox_examples/servers'
            }]
        }, {
            type: 'category',
            label: 'Stacks',
            collapsed: true,
            items: [{
                type: 'autogenerated',
                dirName: 'devbox_examples/stacks'
            }]
        }]
    }, {
        type: 'doc',
        id: 'faq'
    }],
};

export default sidebars;
